@@ -144,13 +144,12 @@ as.ppp.sf = function(X, ...) {
 	if (st_dimension(X[1,]) == 2)
 		X = X[-1,]
 	st_geometry(X) = NULL # remove geometry column
-	if (ncol(X) > 1)
-		warning("only first attribute column is used for marks")
 
-	if (ncol(X) == 0)
+	if (ncol(X) == 0) {
 		pp
-	else 
-		spatstat.geom::setmarks(pp, X[1])
+	} else {
+		spatstat.geom::setmarks(pp, X)
+	}
 }
 
 as.owin.POLYGON = function(W, ..., fatal, check_polygons = TRUE) {
@@ -196,7 +195,7 @@ as.owin.sf = function(W, ...) {
 }
 
 #' @export
-st_as_sfc.owin = function(x, ...) {
+st_as_sfc.owin = function(x, ..., crs = NA) {
 # FROM: methods for coercion to Spatial Polygons by Adrian Baddeley, pkg maptools
 	check_spatstat("spatstat.geom")
 	# Check internal spatstat multiplier:
@@ -221,6 +220,7 @@ st_as_sfc.owin = function(x, ...) {
 		w = which.min(st_area(exteriors[ cb[[i]] ]))
 		pieces[[w]] = st_polygon(c(unclass(pieces[[w]]), unclass(holes[[i]])))
 	}
+	st_crs(pieces) = crs
 	if (length(pieces) > 1) # multiple POLYGONs, collapse:
 		st_sfc(do.call(c, pieces))
 	else
