@@ -302,7 +302,8 @@ gdal_polygonize = function(x, mask = NULL, file = tempfile(), driver = "GTiff",
 		else
 			character(0)
 
-	pol = CPL_polygonize(file, mask_name, "GTiff", "Memory", "foo", options, 0, 
+	mem = ifelse(compareVersion(sf_extSoftVersion()["GDAL"], "3.11.0") >= 0, "MEM", "Memory")
+	pol = CPL_polygonize(file, mask_name, "GTiff", mem, "foo", options, 0, 
 		contour_options, use_contours, use_integer)
 	out = process_cpl_read_ogr(pol, quiet = TRUE)
 	names(out)[1] = names(x)[1]
@@ -340,9 +341,10 @@ gdal_rasterize = function(sf, x, gt, file, driver = "GTiff", options = character
 #' @rdname gdal
 #' @param f gdal raster data source filename
 #' @param pts points matrix
-#' @param bilinear logical; use bilinear interpolation, rather than nearest neighbor?
-gdal_extract = function(f, pts, bilinear = FALSE) {
-	CPL_extract(f, pts, as.logical(bilinear))
+#' @param resampling character; resampling method; for method cubic or cubicspline, 
+#' `stars_proxy` objects should be used and GDAL should have version >= 3.10.0
+gdal_extract = function(f, pts, resampling = c("nearest", "bilinear", "cubic", "cubicspline")) {
+	CPL_extract(f, pts, match.arg(resampling))
 }
 
 #' @rdname gdal
