@@ -76,11 +76,23 @@ crs <- gdal_crs(tif)
 try(gdal_metadata("foo"))
 gdal_metadata(tif)
 
+suppressMessages(
+suppressWarnings(
 if (require(stars, quietly = TRUE)) {
 	p = normalizePath(system.file("nc/ones.zarr.zip", package = "sf"))
 	z = paste0('ZARR:/vsizip/"', p, '"/ones.zarr')
-	gdal_utils("mdiminfo", z)
-	cat("\n")
-	print(read_stars(z, normalize_path = FALSE))
-	print(read_mdim(z, normalize_path = FALSE))
+	d = try(gdal_utils("mdiminfo", z), silent = TRUE)
+	if (!inherits(d, "try-error")) {
+		print(d)
+		cat("\n")
+	}
+	e = try(read_stars(z, normalize_path = FALSE), silent = TRUE)
+	f = try(read_mdim(z, normalize_path = FALSE), silent = TRUE)
+	if (inherits(e, "try-error") || inherits(f, "try-error")) {
+		print("Cannot read blosc-compressed Zarr file: blosc not supported?")
+	} else { 
+		print(e)
+		print(f)
+	}
 }
+))
